@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-02-06'; # DATE
-our $VERSION = '0.84'; # VERSION
+our $DATE = '2015-02-21'; # DATE
+our $VERSION = '0.85'; # VERSION
 
 use 5.010001;
 use strict;
@@ -362,7 +362,7 @@ sub list_subcommands {
 
 sub status2exitcode {
     my ($self, $status) = @_;
-    return 0 if $status == 200;
+    return 0 if $status =~ /^2..|304/;
     $status - 300;
 }
 
@@ -1142,7 +1142,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.84 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-06.
+This document describes version 0.85 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-21.
 
 =head1 DESCRIPTION
 
