@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-02-06'; # DATE
-our $VERSION = '0.84'; # VERSION
+our $DATE = '2015-02-21'; # DATE
+our $VERSION = '0.85'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -410,7 +410,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 0.84 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-06.
+This document describes version 0.85 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-21.
 
 =head1 SYNOPSIS
 
@@ -418,101 +418,7 @@ See L<Perinci::CmdLine::Manual::Examples>.
 
 =head1 DESCRIPTION
 
-Perinci::CmdLine::Lite (hereby P::C::Lite) is a lightweight (low startup
-overhead, minimal dependencies) alternative to L<Perinci::CmdLine> (hereby
-P::C). It offers a subset of functionality and a compatible API. Unless you use
-the unsupported features of P::C, P::C::Lite is a drop-in replacement for P::C
-(also see L<Perinci::CmdLine::Any> for automatic fallback).
-
-P::C::Lite stays lightweight by avoiding the use of libraries that have large
-dependencies or add too much to startup overhead. This includes
-L<Perinci::Access> for metadata access, L<Data::Sah> for validator generation,
-L<Text::ANSITable> for formatting results, and L<Log::Any::App> (which uses
-L<Log::Log4perl>) for logging.
-
-P::C::Lite attributes default to condition of low startup overhead. For example,
-C<log> is by default off instead of on like in P::C.
-
-I first developed P::C::Lite mainly for CLI applications that utilize shell tab
-completion as their main feature, e.g. L<App::PMUtils>, L<App::ProgUtils>,
-L<App::GitUtils>.
-
-Below is summary of the differences between P::C::Lite and P::C:
-
-=over
-
-=item * P::C::Lite starts much faster
-
-The target is under 0.04-0.05s to make shell tab completion convenient. On the
-other hand, P::C application can spend between 0.20-0.50s before displaying
-output, due to various abovementioned overheads: loading more libraries,
-validator code generation, etc.
-
-=item * P::C::Lite uses simpler formatting
-
-Instead of L<Perinci::Result::Format> (especially for 'text*' formats which use
-L<Data::Format::Pretty::Console> and L<Text::ANSITable>), to keep dependencies
-minimal and formatting quick, P::C::Lite uses the following simple rules that
-work for a significant portion of common data structures:
-
-1) if result is undef, print nothing.
-
-2) if result is scalar, print it (with newline automatically added).
-
-3) if result is an array of scalars (check at most 5 first rows), print it one
-line for each element.
-
-4) if result is a hash of scalars (check at most 5 keys), print a two column
-table, first column is key and second column is value. Keys will be sorted.
-
-5) if result is an array of hashes of scalars (check at most 5 elements), print
-as table.
-
-6) if result is an array of arrays of scalars (check at most 5 elements), print
-as table.
-
-7) otherwise print as JSON (after cleaning it with L<Data::Clean::JSON>).
-
-YAML and the other formats are not supported.
-
-Table is printed using the more lightweight and much faster
-L<Text::Table::Tiny>.
-
-=item * No support for some protocols
-
-Instead of L<Perinci::Access>, this module uses the more lightweight alternative
-L<Perinci::Access::Lite> which does not support some URL schemes. http/https and
-local are supported though.
-
-=item * No automatic validation from schema in P::C::Lite
-
-Since code wrapping and schema code generation done by L<Perinci::Sub::Wrapper>
-and L<Data::Sah> (which are called automatically by Perinci::Access, but not by
-Perinci::Access::Lite) adds too much startup overhead.
-
-=item * P::C::Lite does not support color themes
-
-=item * P::C::Lite does not support undo
-
-=item * P::C::Lite currently has simpler logging
-
-Only logging to screen is supported, using
-L<Log::Any::Adapter::ScreenColoredLevel>.
-
-=item * P::C::Lite does not support I18N
-
-=item * P::C::Lite does not yet support these environment variables
-
- PERINCI_CMDLINE_COLOR_THEME
- PERINCI_CMDLINE_SERVER
- COLOR
- UTF8
-
-=item * In passing command-line object to functions, P::C::Lite object is passed
-
-Some functions might expect a L<Perinci::CmdLine> instance.
-
-=back
+See L<Perinci::CmdLine::Manual>.
 
 =for Pod::Coverage ^(BUILD|get_meta|hook_.+|run_.+)$
 
